/*
 *   ORXONOX - the hottest 3D action shooter ever to exist
 *                    > www.orxonox.net <
 *
 *
 *   License notice:
 *
 *   This program is free software; you can redistribute it and/or
 *   modify it under the terms of the GNU General Public License
 *   as published by the Free Software Foundation; either version 2
 *   of the License, or (at your option) any later version.
 *
 *   This program is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU General Public License for more details.
 *
 *   You should have received a copy of the GNU General Public License
 *   along with this program; if not, write to the Free Software
 *   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 *
 *   Author:
 *      Martin Polak
 *   Co-authors:
 *      simonmie
 *
 */

/**
    @file Discharger.cc
    @brief Definition of the Discharger class.
*/

#include "Discharger.h"

#include "core/CoreIncludes.h"

#include "weaponsystem/Weapon.h"
#include "weaponsystem/WeaponPack.h"
#include "weaponsystem/WeaponSystem.h"
#include "worldentities/pawns/Pawn.h"

#include "weapons/projectiles/BillboardProjectile.h"

namespace orxonox
{
    RegisterClass(Discharger);

    Discharger::Discharger(Context* context) : WeaponMode(context)
    {
        RegisterObject(Discharger);

        this->reloadTime_ = 0.23f;
        this->damage_ = 90.01f;
        this->speed_ = 90.01f;
        this->charges_ = 0;

        this->setMunitionName("LaserMunition");
        this->setFireSound("sounds/Weapon_LaserFire.ogg");
        this->setReloadSound("sounds/Reload_LaserFire.ogg", 0.8);

        hudImageString_ = "Orxonox/WSHUD_WM_LaserFire";
    }

    void Discharger::fire()
    {
        charges_ += 1;
        orxout() << "c = " << charges_ << endl;
    }
    
    void Discharger::release()
    {
        orxout() << "release c = " << charges_ << endl;
        BillboardProjectile* projectile = new BillboardProjectile(this->getContext());

        this->computeMuzzleParameters(this->getWeapon()->getWeaponPack()->getWeaponSystem()->getPawn()->getAimPosition());
        projectile->setOrientation(this->getMuzzleOrientation());
        projectile->setPosition(this->getMuzzlePosition());
        projectile->setVelocity(this->getMuzzleDirection() * this->speed_ * charges_);

        projectile->setShooter(this->getWeapon()->getWeaponPack()->getWeaponSystem()->getPawn());
        projectile->setDamage(this->getDamage() * charges_);
        projectile->setShieldDamage(this->getShieldDamage() * charges_);
        projectile->setHealthDamage(this->getHealthDamage() * charges_);
        this->charges_ = 0;
    }
}